# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/dataproc/v1/job_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/dataproc/v1/job_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.dataproc.v1 import job_pb2 as yandex_dot_cloud_dot_dataproc_dot_v1_dot_job__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/dataproc/v1/job_service.proto\x12\x18yandex.cloud.dataproc.v1\x1a\x1cgoogle/api/annotations.proto\x1a\"yandex/cloud/dataproc/v1/job.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\"O\n\rGetJobRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\x06job_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x8d\x01\n\x0fListJobsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"X\n\x10ListJobsResponse\x12+\n\x04jobs\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.dataproc.v1.Job\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xdf\x02\n\x10\x43reateJobRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12?\n\rmapreduce_job\x18\x03 \x01(\x0b\x32&.yandex.cloud.dataproc.v1.MapreduceJobH\x00\x12\x37\n\tspark_job\x18\x04 \x01(\x0b\x32\".yandex.cloud.dataproc.v1.SparkJobH\x00\x12;\n\x0bpyspark_job\x18\x05 \x01(\x0b\x32$.yandex.cloud.dataproc.v1.PysparkJobH\x00\x12\x35\n\x08hive_job\x18\x06 \x01(\x0b\x32!.yandex.cloud.dataproc.v1.HiveJobH\x00\x42\n\n\x08job_spec\"O\n\x11\x43reateJobMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x18\n\x06job_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"R\n\x10\x43\x61ncelJobRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\x06job_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x11ListJobLogRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x18\n\x06job_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12 \n\tpage_size\x18\x03 \x01(\x03\x42\r\xfa\xc7\x31\t<=1048576\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\">\n\x12ListJobLogResponse\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xb1\x06\n\nJobService\x12\x8e\x01\n\x04List\x12).yandex.cloud.dataproc.v1.ListJobsRequest\x1a*.yandex.cloud.dataproc.v1.ListJobsResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/dataproc/v1/clusters/{cluster_id}/jobs\x12\xa7\x01\n\x06\x43reate\x12*.yandex.cloud.dataproc.v1.CreateJobRequest\x1a!.yandex.cloud.operation.Operation\"N\xb2\xd2*\x18\n\x11\x43reateJobMetadata\x12\x03Job\x82\xd3\xe4\x93\x02,\"\'/dataproc/v1/clusters/{cluster_id}/jobs:\x01*\x12\x87\x01\n\x03Get\x12\'.yandex.cloud.dataproc.v1.GetJobRequest\x1a\x1d.yandex.cloud.dataproc.v1.Job\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/dataproc/v1/clusters/{cluster_id}/jobs/{job_id}\x12\xa3\x01\n\x07ListLog\x12+.yandex.cloud.dataproc.v1.ListJobLogRequest\x1a,.yandex.cloud.dataproc.v1.ListJobLogResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/dataproc/v1/clusters/{cluster_id}/jobs/{job_id}:logs\x12\xb7\x01\n\x06\x43\x61ncel\x12*.yandex.cloud.dataproc.v1.CancelJobRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*\x18\n\x11\x43reateJobMetadata\x12\x03Job\x82\xd3\xe4\x93\x02<\"7/dataproc/v1/clusters/{cluster_id}/jobs/{job_id}:cancel:\x01*Bk\n\x1cyandex.cloud.api.dataproc.v1B\x04PHJSZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/v1;dataprocb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.dataproc.v1.job_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034yandex.cloud.api.dataproc.v1B\004PHJSZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/v1;dataproc'
  _globals['_GETJOBREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETJOBREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETJOBREQUEST'].fields_by_name['job_id']._loaded_options = None
  _globals['_GETJOBREQUEST'].fields_by_name['job_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTJOBSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTJOBSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTJOBSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTJOBSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTJOBSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTJOBSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTJOBSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTJOBSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATEJOBREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATEJOBREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEJOBREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_CREATEJOBMETADATA'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATEJOBMETADATA'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEJOBMETADATA'].fields_by_name['job_id']._loaded_options = None
  _globals['_CREATEJOBMETADATA'].fields_by_name['job_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_CANCELJOBREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CANCELJOBREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CANCELJOBREQUEST'].fields_by_name['job_id']._loaded_options = None
  _globals['_CANCELJOBREQUEST'].fields_by_name['job_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTJOBLOGREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTJOBLOGREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTJOBLOGREQUEST'].fields_by_name['job_id']._loaded_options = None
  _globals['_LISTJOBLOGREQUEST'].fields_by_name['job_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTJOBLOGREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTJOBLOGREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\t<=1048576'
  _globals['_LISTJOBLOGREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTJOBLOGREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_JOBSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_JOBSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002)\022\'/dataproc/v1/clusters/{cluster_id}/jobs'
  _globals['_JOBSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_JOBSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\030\n\021CreateJobMetadata\022\003Job\202\323\344\223\002,\"\'/dataproc/v1/clusters/{cluster_id}/jobs:\001*'
  _globals['_JOBSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_JOBSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0022\0220/dataproc/v1/clusters/{cluster_id}/jobs/{job_id}'
  _globals['_JOBSERVICE'].methods_by_name['ListLog']._loaded_options = None
  _globals['_JOBSERVICE'].methods_by_name['ListLog']._serialized_options = b'\202\323\344\223\0027\0225/dataproc/v1/clusters/{cluster_id}/jobs/{job_id}:logs'
  _globals['_JOBSERVICE'].methods_by_name['Cancel']._loaded_options = None
  _globals['_JOBSERVICE'].methods_by_name['Cancel']._serialized_options = b'\262\322*\030\n\021CreateJobMetadata\022\003Job\202\323\344\223\002<\"7/dataproc/v1/clusters/{cluster_id}/jobs/{job_id}:cancel:\001*'
  _globals['_GETJOBREQUEST']._serialized_start=243
  _globals['_GETJOBREQUEST']._serialized_end=322
  _globals['_LISTJOBSREQUEST']._serialized_start=325
  _globals['_LISTJOBSREQUEST']._serialized_end=466
  _globals['_LISTJOBSRESPONSE']._serialized_start=468
  _globals['_LISTJOBSRESPONSE']._serialized_end=556
  _globals['_CREATEJOBREQUEST']._serialized_start=559
  _globals['_CREATEJOBREQUEST']._serialized_end=910
  _globals['_CREATEJOBMETADATA']._serialized_start=912
  _globals['_CREATEJOBMETADATA']._serialized_end=991
  _globals['_CANCELJOBREQUEST']._serialized_start=993
  _globals['_CANCELJOBREQUEST']._serialized_end=1075
  _globals['_LISTJOBLOGREQUEST']._serialized_start=1078
  _globals['_LISTJOBLOGREQUEST']._serialized_end=1222
  _globals['_LISTJOBLOGRESPONSE']._serialized_start=1224
  _globals['_LISTJOBLOGRESPONSE']._serialized_end=1286
  _globals['_JOBSERVICE']._serialized_start=1289
  _globals['_JOBSERVICE']._serialized_end=2106
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/datatransfer/v1/transfer.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/datatransfer/v1/transfer.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.datatransfer.v1 import endpoint_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/datatransfer/v1/transfer.proto\x12\x1cyandex.cloud.datatransfer.v1\x1a+yandex/cloud/datatransfer/v1/endpoint.proto\"\xae\x05\n\x08Transfer\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x42\n\x06labels\x18\x06 \x03(\x0b\x32\x32.yandex.cloud.datatransfer.v1.Transfer.LabelsEntry\x12\x36\n\x06source\x18\x07 \x01(\x0b\x32&.yandex.cloud.datatransfer.v1.Endpoint\x12\x36\n\x06target\x18\x08 \x01(\x0b\x32&.yandex.cloud.datatransfer.v1.Endpoint\x12\x36\n\x07runtime\x18\t \x01(\x0b\x32%.yandex.cloud.datatransfer.v1.Runtime\x12<\n\x06status\x18\n \x01(\x0e\x32,.yandex.cloud.datatransfer.v1.TransferStatus\x12\x38\n\x04type\x18\x0c \x01(\x0e\x32*.yandex.cloud.datatransfer.v1.TransferType\x12\x0f\n\x07warning\x18\x0f \x01(\t\x12\x44\n\x0etransformation\x18\x11 \x01(\x0b\x32,.yandex.cloud.datatransfer.v1.Transformation\x12?\n\x0c\x64\x61ta_objects\x18\x13 \x01(\x0b\x32).yandex.cloud.datatransfer.v1.DataObjects\x12\x11\n\tprestable\x18\x16 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x03\x10\x04J\x04\x08\x0b\x10\x0cJ\x04\x08\r\x10\x0fJ\x04\x08\x10\x10\x11J\x04\x08\x12\x10\x13J\x04\x08\x14\x10\x16\"Y\n\x07Runtime\x12=\n\nyc_runtime\x18\x04 \x01(\x0b\x32\'.yandex.cloud.datatransfer.v1.YcRuntimeH\x00\x42\t\n\x07runtimeJ\x04\x08\x01\x10\x04\"@\n\x14ShardingUploadParams\x12\x11\n\tjob_count\x18\x01 \x01(\x03\x12\x15\n\rprocess_count\x18\x02 \x01(\x03\"u\n\tYcRuntime\x12\x11\n\tjob_count\x18\x01 \x01(\x03\x12O\n\x13upload_shard_params\x18\x08 \x01(\x0b\x32\x32.yandex.cloud.datatransfer.v1.ShardingUploadParamsJ\x04\x08\x02\x10\x08\"m\n\x0cMaskFunction\x12L\n\x12mask_function_hash\x18\x01 \x01(\x0b\x32..yandex.cloud.datatransfer.v1.MaskFunctionHashH\x00\x42\x0f\n\rmask_function\"-\n\x10MaskFunctionHash\x12\x19\n\x11user_defined_salt\x18\x01 \x01(\t\">\n\x0cTablesFilter\x12\x16\n\x0einclude_tables\x18\x01 \x03(\t\x12\x16\n\x0e\x65xclude_tables\x18\x02 \x03(\t\"A\n\rColumnsFilter\x12\x17\n\x0finclude_columns\x18\x01 \x03(\t\x12\x17\n\x0f\x65xclude_columns\x18\x02 \x03(\t\"\xa1\x01\n\x14MaskFieldTransformer\x12:\n\x06tables\x18\x01 \x01(\x0b\x32*.yandex.cloud.datatransfer.v1.TablesFilter\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t\x12<\n\x08\x66unction\x18\x03 \x01(\x0b\x32*.yandex.cloud.datatransfer.v1.MaskFunction\"\x94\x01\n\x18\x46ilterColumnsTransformer\x12:\n\x06tables\x18\x01 \x01(\x0b\x32*.yandex.cloud.datatransfer.v1.TablesFilter\x12<\n\x07\x63olumns\x18\x02 \x01(\x0b\x32+.yandex.cloud.datatransfer.v1.ColumnsFilter\")\n\x05Table\x12\x12\n\nname_space\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x80\x01\n\x0bRenameTable\x12:\n\roriginal_name\x18\x01 \x01(\x0b\x32#.yandex.cloud.datatransfer.v1.Table\x12\x35\n\x08new_name\x18\x02 \x01(\x0b\x32#.yandex.cloud.datatransfer.v1.Table\"[\n\x17RenameTablesTransformer\x12@\n\rrename_tables\x18\x01 \x03(\x0b\x32).yandex.cloud.datatransfer.v1.RenameTable\"h\n\x1cReplacePrimaryKeyTransformer\x12:\n\x06tables\x18\x01 \x01(\x0b\x32*.yandex.cloud.datatransfer.v1.TablesFilter\x12\x0c\n\x04keys\x18\x02 \x03(\t\"\x8f\x01\n\x13ToStringTransformer\x12:\n\x06tables\x18\x01 \x01(\x0b\x32*.yandex.cloud.datatransfer.v1.TablesFilter\x12<\n\x07\x63olumns\x18\x02 \x01(\x0b\x32+.yandex.cloud.datatransfer.v1.ColumnsFilter\"\xa4\x01\n\x12SharderTransformer\x12:\n\x06tables\x18\x01 \x01(\x0b\x32*.yandex.cloud.datatransfer.v1.TablesFilter\x12<\n\x07\x63olumns\x18\x02 \x01(\x0b\x32+.yandex.cloud.datatransfer.v1.ColumnsFilter\x12\x14\n\x0cshards_count\x18\x03 \x01(\x03\"y\n\x18TableSplitterTransformer\x12:\n\x06tables\x18\x01 \x01(\x0b\x32*.yandex.cloud.datatransfer.v1.TablesFilter\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t\x12\x10\n\x08splitter\x18\x03 \x01(\t\"x\n\x15\x46ilterRowsTransformer\x12:\n\x06tables\x18\x01 \x01(\x0b\x32*.yandex.cloud.datatransfer.v1.TablesFilter\x12\x12\n\x06\x66ilter\x18\x02 \x01(\tB\x02\x18\x01\x12\x0f\n\x07\x66ilters\x18\x03 \x03(\t\"\xc6\x05\n\x0bTransformer\x12H\n\nmask_field\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.datatransfer.v1.MaskFieldTransformerH\x00\x12P\n\x0e\x66ilter_columns\x18\x02 \x01(\x0b\x32\x36.yandex.cloud.datatransfer.v1.FilterColumnsTransformerH\x00\x12N\n\rrename_tables\x18\x04 \x01(\x0b\x32\x35.yandex.cloud.datatransfer.v1.RenameTablesTransformerH\x00\x12Y\n\x13replace_primary_key\x18\x06 \x01(\x0b\x32:.yandex.cloud.datatransfer.v1.ReplacePrimaryKeyTransformerH\x00\x12N\n\x11\x63onvert_to_string\x18\x07 \x01(\x0b\x32\x31.yandex.cloud.datatransfer.v1.ToStringTransformerH\x00\x12O\n\x13sharder_transformer\x18\t \x01(\x0b\x32\x30.yandex.cloud.datatransfer.v1.SharderTransformerH\x00\x12\\\n\x1atable_splitter_transformer\x18\r \x01(\x0b\x32\x36.yandex.cloud.datatransfer.v1.TableSplitterTransformerH\x00\x12J\n\x0b\x66ilter_rows\x18\x0e \x01(\x0b\x32\x33.yandex.cloud.datatransfer.v1.FilterRowsTransformerH\x00\x42\r\n\x0btransformerJ\x04\x08\x03\x10\x04J\x04\x08\x05\x10\x06J\x04\x08\x08\x10\tJ\x04\x08\n\x10\r\"Q\n\x0eTransformation\x12?\n\x0ctransformers\x18\x01 \x03(\x0b\x32).yandex.cloud.datatransfer.v1.Transformer\"&\n\x0b\x44\x61taObjects\x12\x17\n\x0finclude_objects\x18\x01 \x03(\t*p\n\x0cTransferType\x12\x1d\n\x19TRANSFER_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16SNAPSHOT_AND_INCREMENT\x10\x01\x12\x11\n\rSNAPSHOT_ONLY\x10\x02\x12\x12\n\x0eINCREMENT_ONLY\x10\x03*\x9b\x01\n\x0eTransferStatus\x12\x1f\n\x1bTRANSFER_STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07\x43REATED\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\x0c\n\x08STOPPING\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\t\n\x05\x45RROR\x10\x06\x12\x10\n\x0cSNAPSHOTTING\x10\x07\x12\x08\n\x04\x44ONE\x10\x08\x42q\n yandex.cloud.api.datatransfer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1;datatransferb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datatransfer.v1.transfer_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n yandex.cloud.api.datatransfer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1;datatransfer'
  _globals['_TRANSFER_LABELSENTRY']._loaded_options = None
  _globals['_TRANSFER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_FILTERROWSTRANSFORMER'].fields_by_name['filter']._loaded_options = None
  _globals['_FILTERROWSTRANSFORMER'].fields_by_name['filter']._serialized_options = b'\030\001'
  _globals['_TRANSFERTYPE']._serialized_start=3458
  _globals['_TRANSFERTYPE']._serialized_end=3570
  _globals['_TRANSFERSTATUS']._serialized_start=3573
  _globals['_TRANSFERSTATUS']._serialized_end=3728
  _globals['_TRANSFER']._serialized_start=123
  _globals['_TRANSFER']._serialized_end=809
  _globals['_TRANSFER_LABELSENTRY']._serialized_start=728
  _globals['_TRANSFER_LABELSENTRY']._serialized_end=773
  _globals['_RUNTIME']._serialized_start=811
  _globals['_RUNTIME']._serialized_end=900
  _globals['_SHARDINGUPLOADPARAMS']._serialized_start=902
  _globals['_SHARDINGUPLOADPARAMS']._serialized_end=966
  _globals['_YCRUNTIME']._serialized_start=968
  _globals['_YCRUNTIME']._serialized_end=1085
  _globals['_MASKFUNCTION']._serialized_start=1087
  _globals['_MASKFUNCTION']._serialized_end=1196
  _globals['_MASKFUNCTIONHASH']._serialized_start=1198
  _globals['_MASKFUNCTIONHASH']._serialized_end=1243
  _globals['_TABLESFILTER']._serialized_start=1245
  _globals['_TABLESFILTER']._serialized_end=1307
  _globals['_COLUMNSFILTER']._serialized_start=1309
  _globals['_COLUMNSFILTER']._serialized_end=1374
  _globals['_MASKFIELDTRANSFORMER']._serialized_start=1377
  _globals['_MASKFIELDTRANSFORMER']._serialized_end=1538
  _globals['_FILTERCOLUMNSTRANSFORMER']._serialized_start=1541
  _globals['_FILTERCOLUMNSTRANSFORMER']._serialized_end=1689
  _globals['_TABLE']._serialized_start=1691
  _globals['_TABLE']._serialized_end=1732
  _globals['_RENAMETABLE']._serialized_start=1735
  _globals['_RENAMETABLE']._serialized_end=1863
  _globals['_RENAMETABLESTRANSFORMER']._serialized_start=1865
  _globals['_RENAMETABLESTRANSFORMER']._serialized_end=1956
  _globals['_REPLACEPRIMARYKEYTRANSFORMER']._serialized_start=1958
  _globals['_REPLACEPRIMARYKEYTRANSFORMER']._serialized_end=2062
  _globals['_TOSTRINGTRANSFORMER']._serialized_start=2065
  _globals['_TOSTRINGTRANSFORMER']._serialized_end=2208
  _globals['_SHARDERTRANSFORMER']._serialized_start=2211
  _globals['_SHARDERTRANSFORMER']._serialized_end=2375
  _globals['_TABLESPLITTERTRANSFORMER']._serialized_start=2377
  _globals['_TABLESPLITTERTRANSFORMER']._serialized_end=2498
  _globals['_FILTERROWSTRANSFORMER']._serialized_start=2500
  _globals['_FILTERROWSTRANSFORMER']._serialized_end=2620
  _globals['_TRANSFORMER']._serialized_start=2623
  _globals['_TRANSFORMER']._serialized_end=3333
  _globals['_TRANSFORMATION']._serialized_start=3335
  _globals['_TRANSFORMATION']._serialized_end=3416
  _globals['_DATAOBJECTS']._serialized_start=3418
  _globals['_DATAOBJECTS']._serialized_end=3456
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.mdb.postgresql.v1.perf_diag_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class PerformanceDiagnosticsServiceStub:
    """A set of methods for PostgreSQL performance diagnostics."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    ListRawSessionStates: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.postgresql.v1.perf_diag_service_pb2.ListRawSessionStatesRequest,
        yandex.cloud.mdb.postgresql.v1.perf_diag_service_pb2.ListRawSessionStatesResponse,
    ]
    """Retrieves raw statistics on sessions. Corresponds to the [pg_stat_activity view](https://www.postgresql.org/docs/current/monitoring-stats.html#MONITORING-PG-STAT-ACTIVITY-VIEW)."""

    ListRawStatements: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.postgresql.v1.perf_diag_service_pb2.ListRawStatementsRequest,
        yandex.cloud.mdb.postgresql.v1.perf_diag_service_pb2.ListRawStatementsResponse,
    ]
    """Retrieves statistics on planning and execution of SQL statements (queries)."""

class PerformanceDiagnosticsServiceAsyncStub:
    """A set of methods for PostgreSQL performance diagnostics."""

    ListRawSessionStates: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.postgresql.v1.perf_diag_service_pb2.ListRawSessionStatesRequest,
        yandex.cloud.mdb.postgresql.v1.perf_diag_service_pb2.ListRawSessionStatesResponse,
    ]
    """Retrieves raw statistics on sessions. Corresponds to the [pg_stat_activity view](https://www.postgresql.org/docs/current/monitoring-stats.html#MONITORING-PG-STAT-ACTIVITY-VIEW)."""

    ListRawStatements: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.postgresql.v1.perf_diag_service_pb2.ListRawStatementsRequest,
        yandex.cloud.mdb.postgresql.v1.perf_diag_service_pb2.ListRawStatementsResponse,
    ]
    """Retrieves statistics on planning and execution of SQL statements (queries)."""

class PerformanceDiagnosticsServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for PostgreSQL performance diagnostics."""

    @abc.abstractmethod
    def ListRawSessionStates(
        self,
        request: yandex.cloud.mdb.postgresql.v1.perf_diag_service_pb2.ListRawSessionStatesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.postgresql.v1.perf_diag_service_pb2.ListRawSessionStatesResponse, collections.abc.Awaitable[yandex.cloud.mdb.postgresql.v1.perf_diag_service_pb2.ListRawSessionStatesResponse]]:
        """Retrieves raw statistics on sessions. Corresponds to the [pg_stat_activity view](https://www.postgresql.org/docs/current/monitoring-stats.html#MONITORING-PG-STAT-ACTIVITY-VIEW)."""

    @abc.abstractmethod
    def ListRawStatements(
        self,
        request: yandex.cloud.mdb.postgresql.v1.perf_diag_service_pb2.ListRawStatementsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.postgresql.v1.perf_diag_service_pb2.ListRawStatementsResponse, collections.abc.Awaitable[yandex.cloud.mdb.postgresql.v1.perf_diag_service_pb2.ListRawStatementsResponse]]:
        """Retrieves statistics on planning and execution of SQL statements (queries)."""

def add_PerformanceDiagnosticsServiceServicer_to_server(servicer: PerformanceDiagnosticsServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/dataproc/v1/cluster.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/dataproc/v1/cluster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.dataproc.v1 import common_pb2 as yandex_dot_cloud_dot_dataproc_dot_v1_dot_common__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/dataproc/v1/cluster.proto\x12\x18yandex.cloud.dataproc.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a%yandex/cloud/dataproc/v1/common.proto\x1a\x1dyandex/cloud/validation.proto\"\x99\x07\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x04name\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04\x31-63\x12\x1e\n\x0b\x64\x65scription\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05\x30-256\x12G\n\x06labels\x18\x06 \x03(\x0b\x32-.yandex.cloud.dataproc.v1.Cluster.LabelsEntryB\x08\x82\xc8\x31\x04<=64\x12\x38\n\nmonitoring\x18\x07 \x03(\x0b\x32$.yandex.cloud.dataproc.v1.Monitoring\x12\x37\n\x06\x63onfig\x18\x08 \x01(\x0b\x32\'.yandex.cloud.dataproc.v1.ClusterConfig\x12\x30\n\x06health\x18\t \x01(\x0e\x32 .yandex.cloud.dataproc.v1.Health\x12\x38\n\x06status\x18\n \x01(\x0e\x32(.yandex.cloud.dataproc.v1.Cluster.Status\x12\x0f\n\x07zone_id\x18\x0b \x01(\t\x12\x1a\n\x12service_account_id\x18\x0c \x01(\t\x12\x0e\n\x06\x62ucket\x18\r \x01(\t\x12\x10\n\x08ui_proxy\x18\x0e \x01(\x08\x12\x1a\n\x12security_group_ids\x18\x0f \x03(\t\x12\x16\n\x0ehost_group_ids\x18\x10 \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x11 \x01(\x08\x12\x14\n\x0clog_group_id\x18\x12 \x01(\t\x12\x42\n\x0b\x65nvironment\x18\x13 \x01(\x0e\x32-.yandex.cloud.dataproc.v1.Cluster.Environment\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"k\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08STOPPING\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\x0c\n\x08STARTING\x10\x06\"I\n\x0b\x45nvironment\x12\x1b\n\x17\x45NVIRONMENT_UNSPECIFIED\x10\x00\x12\x0e\n\nPRODUCTION\x10\x01\x12\r\n\tPRESTABLE\x10\x02\"=\n\nMonitoring\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\"\xf1\x03\n\x0cHadoopConfig\x12@\n\x08services\x18\x01 \x03(\x0e\x32..yandex.cloud.dataproc.v1.HadoopConfig.Service\x12J\n\nproperties\x18\x02 \x03(\x0b\x32\x36.yandex.cloud.dataproc.v1.HadoopConfig.PropertiesEntry\x12\x17\n\x0fssh_public_keys\x18\x03 \x03(\t\x12N\n\x16initialization_actions\x18\x04 \x03(\x0b\x32..yandex.cloud.dataproc.v1.InitializationAction\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x01\n\x07Service\x12\x17\n\x13SERVICE_UNSPECIFIED\x10\x00\x12\x08\n\x04HDFS\x10\x01\x12\x08\n\x04YARN\x10\x02\x12\r\n\tMAPREDUCE\x10\x03\x12\x08\n\x04HIVE\x10\x04\x12\x07\n\x03TEZ\x10\x05\x12\r\n\tZOOKEEPER\x10\x06\x12\t\n\x05HBASE\x10\x07\x12\t\n\x05SQOOP\x10\x08\x12\t\n\x05\x46LUME\x10\t\x12\t\n\x05SPARK\x10\n\x12\x0c\n\x08ZEPPELIN\x10\x0b\x12\t\n\x05OOZIE\x10\x0c\x12\x08\n\x04LIVY\x10\r\"[\n\rClusterConfig\x12\x12\n\nversion_id\x18\x01 \x01(\t\x12\x36\n\x06hadoop\x18\x02 \x01(\x0b\x32&.yandex.cloud.dataproc.v1.HadoopConfig\"B\n\x14InitializationAction\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\x12\x0f\n\x07timeout\x18\x03 \x01(\x03\x42\x65\n\x1cyandex.cloud.api.dataproc.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/v1;dataprocb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.dataproc.v1.cluster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034yandex.cloud.api.dataproc.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/v1;dataproc'
  _globals['_CLUSTER_LABELSENTRY']._loaded_options = None
  _globals['_CLUSTER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CLUSTER'].fields_by_name['name']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['name']._serialized_options = b'\212\3101\0041-63'
  _globals['_CLUSTER'].fields_by_name['description']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['description']._serialized_options = b'\212\3101\0050-256'
  _globals['_CLUSTER'].fields_by_name['labels']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['labels']._serialized_options = b'\202\3101\004<=64'
  _globals['_HADOOPCONFIG_PROPERTIESENTRY']._loaded_options = None
  _globals['_HADOOPCONFIG_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_CLUSTER']._serialized_start=172
  _globals['_CLUSTER']._serialized_end=1093
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=864
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=909
  _globals['_CLUSTER_STATUS']._serialized_start=911
  _globals['_CLUSTER_STATUS']._serialized_end=1018
  _globals['_CLUSTER_ENVIRONMENT']._serialized_start=1020
  _globals['_CLUSTER_ENVIRONMENT']._serialized_end=1093
  _globals['_MONITORING']._serialized_start=1095
  _globals['_MONITORING']._serialized_end=1156
  _globals['_HADOOPCONFIG']._serialized_start=1159
  _globals['_HADOOPCONFIG']._serialized_end=1656
  _globals['_HADOOPCONFIG_PROPERTIESENTRY']._serialized_start=1422
  _globals['_HADOOPCONFIG_PROPERTIESENTRY']._serialized_end=1471
  _globals['_HADOOPCONFIG_SERVICE']._serialized_start=1474
  _globals['_HADOOPCONFIG_SERVICE']._serialized_end=1656
  _globals['_CLUSTERCONFIG']._serialized_start=1658
  _globals['_CLUSTERCONFIG']._serialized_end=1749
  _globals['_INITIALIZATIONACTION']._serialized_start=1751
  _globals['_INITIALIZATIONACTION']._serialized_end=1817
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/video/v1/channel_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/video/v1/channel_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.video.v1 import channel_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/video/v1/channel_service.proto\x12\x15yandex.cloud.video.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a#yandex/cloud/video/v1/channel.proto\"5\n\x11GetChannelRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xaf\x01\n\x13ListChannelsRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x1f\n\npage_token\x18\x65 \x01(\tB\x0b\x8a\xc8\x31\x07<=15000\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x1a\n\x06\x66ilter\x18g \x01(\tB\n\x8a\xc8\x31\x06<=1000J\x04\x08\x02\x10\x64\"g\n\x14ListChannelsResponse\x12\x30\n\x08\x63hannels\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.video.v1.Channel\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"\xf1\x02\n\x14\x43reateChannelRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x05title\x18\x02 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=2500\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x8c\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x37.yandex.cloud.video.v1.CreateChannelRequest.LabelsEntryBB\xf2\xc7\x31\x12[-_.@:/0-9a-zA-Z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12\x39\n\x08settings\x18\xc9\x01 \x01(\x0b\x32&.yandex.cloud.video.v1.ChannelSettings\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x05\x08\x04\x10\xc8\x01\"+\n\x15\x43reateChannelMetadata\x12\x12\n\nchannel_id\x18\x01 \x01(\t\"\x9e\x03\n\x14UpdateChannelRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x34\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12\x19\n\x05title\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2500\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x8c\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x37.yandex.cloud.video.v1.UpdateChannelRequest.LabelsEntryBB\xf2\xc7\x31\x12[-_.@:/0-9a-zA-Z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12\x39\n\x08settings\x18\xc9\x01 \x01(\x0b\x32&.yandex.cloud.video.v1.ChannelSettings\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x05\x08\x05\x10\xc8\x01\"+\n\x15UpdateChannelMetadata\x12\x12\n\nchannel_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteChannelRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteChannelMetadata\x12\x12\n\nchannel_id\x18\x01 \x01(\t\"k\n\x1a\x42\x61tchDeleteChannelsRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12&\n\x0b\x63hannel_ids\x18\x02 \x03(\tB\x11\x82\xc8\x31\x05\x31-100\x8a\xc8\x31\x04<=50\"2\n\x1b\x42\x61tchDeleteChannelsMetadata\x12\x13\n\x0b\x63hannel_ids\x18\x01 \x03(\t2\xf8\x0c\n\x0e\x43hannelService\x12x\n\x03Get\x12(.yandex.cloud.video.v1.GetChannelRequest\x1a\x1e.yandex.cloud.video.v1.Channel\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/video/v1/channels/{channel_id}\x12{\n\x04List\x12*.yandex.cloud.video.v1.ListChannelsRequest\x1a+.yandex.cloud.video.v1.ListChannelsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/video/v1/channels\x12\x9b\x01\n\x06\x43reate\x12+.yandex.cloud.video.v1.CreateChannelRequest\x1a!.yandex.cloud.operation.Operation\"A\xb2\xd2* \n\x15\x43reateChannelMetadata\x12\x07\x43hannel\x82\xd3\xe4\x93\x02\x17\"\x12/video/v1/channels:\x01*\x12\xa8\x01\n\x06Update\x12+.yandex.cloud.video.v1.UpdateChannelRequest\x1a!.yandex.cloud.operation.Operation\"N\xb2\xd2* \n\x15UpdateChannelMetadata\x12\x07\x43hannel\x82\xd3\xe4\x93\x02$2\x1f/video/v1/channels/{channel_id}:\x01*\x12\xb3\x01\n\x06\x44\x65lete\x12+.yandex.cloud.video.v1.DeleteChannelRequest\x1a!.yandex.cloud.operation.Operation\"Y\xb2\xd2*.\n\x15\x44\x65leteChannelMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02!*\x1f/video/v1/channels/{channel_id}\x12\xc6\x01\n\x0b\x42\x61tchDelete\x12\x31.yandex.cloud.video.v1.BatchDeleteChannelsRequest\x1a!.yandex.cloud.operation.Operation\"a\xb2\xd2*4\n\x1b\x42\x61tchDeleteChannelsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02#\"\x1e/video/v1/channels:batchDelete:\x01*\x12\xb2\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/video/v1/channels/{resource_id}:listAccessBindings\x12\xf1\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x89\x01\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02\x37\"2/video/v1/channels/{resource_id}:setAccessBindings:\x01*\x12\xfd\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8f\x01\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02:25/video/v1/channels/{resource_id}:updateAccessBindings:\x01*B\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.channel_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_GETCHANNELREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_GETCHANNELREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCHANNELSREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_LISTCHANNELSREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCHANNELSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCHANNELSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_LISTCHANNELSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCHANNELSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\007<=15000'
  _globals['_LISTCHANNELSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTCHANNELSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATECHANNELREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATECHANNELREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATECHANNELREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_CREATECHANNELREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECHANNELREQUEST'].fields_by_name['title']._loaded_options = None
  _globals['_CREATECHANNELREQUEST'].fields_by_name['title']._serialized_options = b'\350\3071\001\212\3101\006<=2500'
  _globals['_CREATECHANNELREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATECHANNELREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\022[-_.@:/0-9a-zA-Z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_UPDATECHANNELREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATECHANNELREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATECHANNELREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_UPDATECHANNELREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECHANNELREQUEST'].fields_by_name['field_mask']._loaded_options = None
  _globals['_UPDATECHANNELREQUEST'].fields_by_name['field_mask']._serialized_options = b'\350\3071\001'
  _globals['_UPDATECHANNELREQUEST'].fields_by_name['title']._loaded_options = None
  _globals['_UPDATECHANNELREQUEST'].fields_by_name['title']._serialized_options = b'\212\3101\006<=2500'
  _globals['_UPDATECHANNELREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATECHANNELREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\022[-_.@:/0-9a-zA-Z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_DELETECHANNELREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_DELETECHANNELREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BATCHDELETECHANNELSREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_BATCHDELETECHANNELSREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BATCHDELETECHANNELSREQUEST'].fields_by_name['channel_ids']._loaded_options = None
  _globals['_BATCHDELETECHANNELSREQUEST'].fields_by_name['channel_ids']._serialized_options = b'\202\3101\0051-100\212\3101\004<=50'
  _globals['_CHANNELSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CHANNELSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002!\022\037/video/v1/channels/{channel_id}'
  _globals['_CHANNELSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CHANNELSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\024\022\022/video/v1/channels'
  _globals['_CHANNELSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CHANNELSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateChannelMetadata\022\007Channel\202\323\344\223\002\027\"\022/video/v1/channels:\001*'
  _globals['_CHANNELSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CHANNELSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateChannelMetadata\022\007Channel\202\323\344\223\002$2\037/video/v1/channels/{channel_id}:\001*'
  _globals['_CHANNELSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CHANNELSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteChannelMetadata\022\025google.protobuf.Empty\202\323\344\223\002!*\037/video/v1/channels/{channel_id}'
  _globals['_CHANNELSERVICE'].methods_by_name['BatchDelete']._loaded_options = None
  _globals['_CHANNELSERVICE'].methods_by_name['BatchDelete']._serialized_options = b'\262\322*4\n\033BatchDeleteChannelsMetadata\022\025google.protobuf.Empty\202\323\344\223\002#\"\036/video/v1/channels:batchDelete:\001*'
  _globals['_CHANNELSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_CHANNELSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\0025\0223/video/v1/channels/{resource_id}:listAccessBindings'
  _globals['_CHANNELSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_CHANNELSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\0027\"2/video/v1/channels/{resource_id}:setAccessBindings:\001*'
  _globals['_CHANNELSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_CHANNELSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002:25/video/v1/channels/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETCHANNELREQUEST']._serialized_start=310
  _globals['_GETCHANNELREQUEST']._serialized_end=363
  _globals['_LISTCHANNELSREQUEST']._serialized_start=366
  _globals['_LISTCHANNELSREQUEST']._serialized_end=541
  _globals['_LISTCHANNELSRESPONSE']._serialized_start=543
  _globals['_LISTCHANNELSRESPONSE']._serialized_end=646
  _globals['_CREATECHANNELREQUEST']._serialized_start=649
  _globals['_CREATECHANNELREQUEST']._serialized_end=1018
  _globals['_CREATECHANNELREQUEST_LABELSENTRY']._serialized_start=966
  _globals['_CREATECHANNELREQUEST_LABELSENTRY']._serialized_end=1011
  _globals['_CREATECHANNELMETADATA']._serialized_start=1020
  _globals['_CREATECHANNELMETADATA']._serialized_end=1063
  _globals['_UPDATECHANNELREQUEST']._serialized_start=1066
  _globals['_UPDATECHANNELREQUEST']._serialized_end=1480
  _globals['_UPDATECHANNELREQUEST_LABELSENTRY']._serialized_start=966
  _globals['_UPDATECHANNELREQUEST_LABELSENTRY']._serialized_end=1011
  _globals['_UPDATECHANNELMETADATA']._serialized_start=1482
  _globals['_UPDATECHANNELMETADATA']._serialized_end=1525
  _globals['_DELETECHANNELREQUEST']._serialized_start=1527
  _globals['_DELETECHANNELREQUEST']._serialized_end=1583
  _globals['_DELETECHANNELMETADATA']._serialized_start=1585
  _globals['_DELETECHANNELMETADATA']._serialized_end=1628
  _globals['_BATCHDELETECHANNELSREQUEST']._serialized_start=1630
  _globals['_BATCHDELETECHANNELSREQUEST']._serialized_end=1737
  _globals['_BATCHDELETECHANNELSMETADATA']._serialized_start=1739
  _globals['_BATCHDELETECHANNELSMETADATA']._serialized_end=1789
  _globals['_CHANNELSERVICE']._serialized_start=1792
  _globals['_CHANNELSERVICE']._serialized_end=3448
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.mdb.spqr.v1.config_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Host(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Host._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: Host._Type.ValueType  # 0
        ROUTER: Host._Type.ValueType  # 2
        """A SPQR Router host."""
        COORDINATOR: Host._Type.ValueType  # 3
        """A SPQR Coordinator host."""
        INFRA: Host._Type.ValueType  # 4
        """A SPQR Infra host (router+coordinator)"""
        POSTGRESQL: Host._Type.ValueType  # 5
        """A PostgreSQL host."""
        EXTERNAL_POSTGRESQL: Host._Type.ValueType  # 6
        """An External PostgreSQL host."""
        MDB_POSTGRESQL: Host._Type.ValueType  # 7
        """A Managed PostgreSQL host"""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: Host.Type.ValueType  # 0
    ROUTER: Host.Type.ValueType  # 2
    """A SPQR Router host."""
    COORDINATOR: Host.Type.ValueType  # 3
    """A SPQR Coordinator host."""
    INFRA: Host.Type.ValueType  # 4
    """A SPQR Infra host (router+coordinator)"""
    POSTGRESQL: Host.Type.ValueType  # 5
    """A PostgreSQL host."""
    EXTERNAL_POSTGRESQL: Host.Type.ValueType  # 6
    """An External PostgreSQL host."""
    MDB_POSTGRESQL: Host.Type.ValueType  # 7
    """A Managed PostgreSQL host"""

    class _Role:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Host._Role.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ROLE_UNKNOWN: Host._Role.ValueType  # 0
        """Role of the host in the cluster is unknown."""
        PRIMARY: Host._Role.ValueType  # 1
        """Host is the primary SPQR server in the cluster."""
        SECONDARY: Host._Role.ValueType  # 2
        """Host is a secondary SPQR server in the cluster."""
        MASTER: Host._Role.ValueType  # 3
        """Host is the master PostgreSQL server in the cluster."""
        REPLICA: Host._Role.ValueType  # 4
        """Host is a replica (standby) PostgreSQL server in the cluster."""

    class Role(_Role, metaclass=_RoleEnumTypeWrapper): ...
    ROLE_UNKNOWN: Host.Role.ValueType  # 0
    """Role of the host in the cluster is unknown."""
    PRIMARY: Host.Role.ValueType  # 1
    """Host is the primary SPQR server in the cluster."""
    SECONDARY: Host.Role.ValueType  # 2
    """Host is a secondary SPQR server in the cluster."""
    MASTER: Host.Role.ValueType  # 3
    """Host is the master PostgreSQL server in the cluster."""
    REPLICA: Host.Role.ValueType  # 4
    """Host is a replica (standby) PostgreSQL server in the cluster."""

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Host._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Host._Health.ValueType  # 0
        """Health of the host is unknown."""
        ALIVE: Host._Health.ValueType  # 1
        """The host is performing all its functions normally."""
        DEAD: Host._Health.ValueType  # 2
        """The host is inoperable, and cannot perform any of its essential functions."""
        DEGRADED: Host._Health.ValueType  # 3
        """The host is degraded, and can perform only some of its essential functions."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Host.Health.ValueType  # 0
    """Health of the host is unknown."""
    ALIVE: Host.Health.ValueType  # 1
    """The host is performing all its functions normally."""
    DEAD: Host.Health.ValueType  # 2
    """The host is inoperable, and cannot perform any of its essential functions."""
    DEGRADED: Host.Health.ValueType  # 3
    """The host is degraded, and can perform only some of its essential functions."""

    @typing.final
    class CPUMetric(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TIMESTAMP_FIELD_NUMBER: builtins.int
        USED_FIELD_NUMBER: builtins.int
        timestamp: builtins.int
        used: builtins.float
        def __init__(
            self,
            *,
            timestamp: builtins.int = ...,
            used: builtins.float = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["timestamp", b"timestamp", "used", b"used"]) -> None: ...

    @typing.final
    class MemoryMetric(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TIMESTAMP_FIELD_NUMBER: builtins.int
        USED_FIELD_NUMBER: builtins.int
        TOTAL_FIELD_NUMBER: builtins.int
        timestamp: builtins.int
        used: builtins.int
        total: builtins.int
        def __init__(
            self,
            *,
            timestamp: builtins.int = ...,
            used: builtins.int = ...,
            total: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["timestamp", b"timestamp", "total", b"total", "used", b"used"]) -> None: ...

    @typing.final
    class DiskMetric(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TIMESTAMP_FIELD_NUMBER: builtins.int
        USED_FIELD_NUMBER: builtins.int
        TOTAL_FIELD_NUMBER: builtins.int
        timestamp: builtins.int
        used: builtins.int
        total: builtins.int
        def __init__(
            self,
            *,
            timestamp: builtins.int = ...,
            used: builtins.int = ...,
            total: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["timestamp", b"timestamp", "total", b"total", "used", b"used"]) -> None: ...

    @typing.final
    class SystemMetrics(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CPU_FIELD_NUMBER: builtins.int
        MEMORY_FIELD_NUMBER: builtins.int
        DISK_FIELD_NUMBER: builtins.int
        @property
        def cpu(self) -> global___Host.CPUMetric: ...
        @property
        def memory(self) -> global___Host.MemoryMetric: ...
        @property
        def disk(self) -> global___Host.DiskMetric: ...
        def __init__(
            self,
            *,
            cpu: global___Host.CPUMetric | None = ...,
            memory: global___Host.MemoryMetric | None = ...,
            disk: global___Host.DiskMetric | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["cpu", b"cpu", "disk", b"disk", "memory", b"memory"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["cpu", b"cpu", "disk", b"disk", "memory", b"memory"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    SERVICES_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    WALLE_LINK_FIELD_NUMBER: builtins.int
    STATE_REASON_FIELD_NUMBER: builtins.int
    SYSTEM_FIELD_NUMBER: builtins.int
    SHARD_NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the SPQR host. The host name is assigned by MDB at creation time, and cannot be changed.
    1-63 characters long.

    The name is unique across all MDB hosts that exist on the platform, as it defines the FQDN of the host.
    """
    cluster_id: builtins.str
    """The ID of the SPQR cluster that the host belongs to."""
    zone_id: builtins.str
    """ID of the availability zone where the SPQR host resides."""
    role: global___Host.Role.ValueType
    """Role of the host in the cluster."""
    health: global___Host.Health.ValueType
    """Status code of the aggregated health of the host."""
    subnet_id: builtins.str
    """ID of the subnet that the host belongs to."""
    assign_public_ip: builtins.bool
    """Flag showing public IP assignment status to this host."""
    type: global___Host.Type.ValueType
    """Host type"""
    walle_link: builtins.str
    """link to wall-e (porto only)"""
    state_reason: builtins.str
    """host state reason from cms (porto only)"""
    shard_name: builtins.str
    """Shard which this host belongs to."""
    @property
    def resources(self) -> yandex.cloud.mdb.spqr.v1.config_pb2.Resources:
        """Resources allocated to the SPQR host."""

    @property
    def services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Service]:
        """Services provided by the host."""

    @property
    def system(self) -> global___Host.SystemMetrics:
        """System metrics"""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        zone_id: builtins.str = ...,
        resources: yandex.cloud.mdb.spqr.v1.config_pb2.Resources | None = ...,
        role: global___Host.Role.ValueType = ...,
        health: global___Host.Health.ValueType = ...,
        services: collections.abc.Iterable[global___Service] | None = ...,
        subnet_id: builtins.str = ...,
        assign_public_ip: builtins.bool = ...,
        type: global___Host.Type.ValueType = ...,
        walle_link: builtins.str = ...,
        state_reason: builtins.str = ...,
        system: global___Host.SystemMetrics | None = ...,
        shard_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources", "system", b"system"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assign_public_ip", b"assign_public_ip", "cluster_id", b"cluster_id", "health", b"health", "name", b"name", "resources", b"resources", "role", b"role", "services", b"services", "shard_name", b"shard_name", "state_reason", b"state_reason", "subnet_id", b"subnet_id", "system", b"system", "type", b"type", "walle_link", b"walle_link", "zone_id", b"zone_id"]) -> None: ...

global___Host = Host

@typing.final
class Service(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Service._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: Service._Type.ValueType  # 0
        ROUTER: Service._Type.ValueType  # 2
        """The host is running a SPQR Router."""
        COORDINATOR: Service._Type.ValueType  # 3
        """The host is running a SPQR Coordinator."""
        INFRA: Service._Type.ValueType  # 4
        """The host is running a SPQR router and coordinator"""
        POSTGRESQL: Service._Type.ValueType  # 5
        """The host is running a PostgreSQL."""
        EXTERNAL_POSTGRESQL: Service._Type.ValueType  # 6
        """The host is running a PostgreSQL."""
        MDB_POSTGRESQL: Service._Type.ValueType  # 7
        """The host is running a PostgreSQL"""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: Service.Type.ValueType  # 0
    ROUTER: Service.Type.ValueType  # 2
    """The host is running a SPQR Router."""
    COORDINATOR: Service.Type.ValueType  # 3
    """The host is running a SPQR Coordinator."""
    INFRA: Service.Type.ValueType  # 4
    """The host is running a SPQR router and coordinator"""
    POSTGRESQL: Service.Type.ValueType  # 5
    """The host is running a PostgreSQL."""
    EXTERNAL_POSTGRESQL: Service.Type.ValueType  # 6
    """The host is running a PostgreSQL."""
    MDB_POSTGRESQL: Service.Type.ValueType  # 7
    """The host is running a PostgreSQL"""

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Service._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Service._Health.ValueType  # 0
        """Health of the server is unknown."""
        ALIVE: Service._Health.ValueType  # 1
        """The server is working normally."""
        DEAD: Service._Health.ValueType  # 2
        """The server is dead or unresponsive."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Service.Health.ValueType  # 0
    """Health of the server is unknown."""
    ALIVE: Service.Health.ValueType  # 1
    """The server is working normally."""
    DEAD: Service.Health.ValueType  # 2
    """The server is dead or unresponsive."""

    TYPE_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    type: global___Service.Type.ValueType
    """Type of the service provided by the host."""
    health: global___Service.Health.ValueType
    """Status code of server availability."""
    def __init__(
        self,
        *,
        type: global___Service.Type.ValueType = ...,
        health: global___Service.Health.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["health", b"health", "type", b"type"]) -> None: ...

global___Service = Service

@typing.final
class HostSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ZONE_ID_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SHARD_NAME_FIELD_NUMBER: builtins.int
    MDB_POSTGRESQL_FIELD_NUMBER: builtins.int
    zone_id: builtins.str
    """ID of the availability zone where the host resides.
    To get a list of available zones, use the [yandex.cloud.compute.v1.ZoneService.List] request.
    """
    subnet_id: builtins.str
    """ID of the subnet that the host should belong to. This subnet should be a part
    of the network that the cluster belongs to.
    The network ID is set in the [Cluster.network_id] field.
    """
    assign_public_ip: builtins.bool
    """Whether the host should get a public IP address on creation.

    After a host has been created, this setting cannot be changed. To remove an assigned public IP, or to assign
    a public IP to a host without one, recreate the host with [assign_public_ip] set as needed.

    Possible values:
    * false - don't assign a public IP to the host.
    * true - the host should have a public IP address.
    """
    type: global___Host.Type.ValueType
    """Type of the host to be deployed."""
    shard_name: builtins.str
    """Name of the shard that the host belongs to.
    If empty, host doesn't belong to any shard
    """
    @property
    def mdb_postgresql(self) -> yandex.cloud.mdb.spqr.v1.config_pb2.MDBPostgreSQL: ...
    def __init__(
        self,
        *,
        zone_id: builtins.str = ...,
        subnet_id: builtins.str = ...,
        assign_public_ip: builtins.bool = ...,
        type: global___Host.Type.ValueType = ...,
        shard_name: builtins.str = ...,
        mdb_postgresql: yandex.cloud.mdb.spqr.v1.config_pb2.MDBPostgreSQL | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["mdb_postgresql", b"mdb_postgresql"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assign_public_ip", b"assign_public_ip", "mdb_postgresql", b"mdb_postgresql", "shard_name", b"shard_name", "subnet_id", b"subnet_id", "type", b"type", "zone_id", b"zone_id"]) -> None: ...

global___HostSpec = HostSpec



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.dataproc.v1.cluster_pb2
import yandex.cloud.dataproc.v1.common_pb2
import yandex.cloud.dataproc.v1.subcluster_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Data Proc cluster.

    To get a cluster ID make a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___GetClusterRequest = GetClusterRequest

@typing.final
class ListClustersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list clusters in.

    To get the folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListClustersResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListClustersResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters clusters listed in the response.

    The expression must specify:
    1. The field name. Currently you can use filtering only on [Cluster.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name=my-cluster`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClustersRequest = ListClustersRequest

@typing.final
class ListClustersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListClustersRequest.page_size], use `next_page_token` as the value
    for the [ListClustersRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def clusters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.dataproc.v1.cluster_pb2.Cluster]:
        """List of clusters in the specified folder."""

    def __init__(
        self,
        *,
        clusters: collections.abc.Iterable[yandex.cloud.dataproc.v1.cluster_pb2.Cluster] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["clusters", b"clusters", "next_page_token", b"next_page_token"]) -> None: ...

global___ListClustersResponse = ListClustersResponse

@typing.final
class CreateSubclusterConfigSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    HOSTS_COUNT_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
    AUTOSCALING_CONFIG_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the subcluster."""
    role: yandex.cloud.dataproc.v1.subcluster_pb2.Role.ValueType
    """Role of the subcluster in the Data Proc cluster."""
    subnet_id: builtins.str
    """ID of the VPC subnet used for hosts in the subcluster."""
    hosts_count: builtins.int
    """Number of hosts in the subcluster."""
    assign_public_ip: builtins.bool
    """Assign public ip addresses for all hosts in subcluter."""
    @property
    def resources(self) -> yandex.cloud.dataproc.v1.common_pb2.Resources:
        """Resource configuration for hosts in the subcluster."""

    @property
    def autoscaling_config(self) -> yandex.cloud.dataproc.v1.subcluster_pb2.AutoscalingConfig:
        """Configuration for instance group based subclusters"""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        role: yandex.cloud.dataproc.v1.subcluster_pb2.Role.ValueType = ...,
        resources: yandex.cloud.dataproc.v1.common_pb2.Resources | None = ...,
        subnet_id: builtins.str = ...,
        hosts_count: builtins.int = ...,
        assign_public_ip: builtins.bool = ...,
        autoscaling_config: yandex.cloud.dataproc.v1.subcluster_pb2.AutoscalingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["autoscaling_config", b"autoscaling_config", "resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assign_public_ip", b"assign_public_ip", "autoscaling_config", b"autoscaling_config", "hosts_count", b"hosts_count", "name", b"name", "resources", b"resources", "role", b"role", "subnet_id", b"subnet_id"]) -> None: ...

global___CreateSubclusterConfigSpec = CreateSubclusterConfigSpec

@typing.final
class UpdateSubclusterConfigSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    HOSTS_COUNT_FIELD_NUMBER: builtins.int
    AUTOSCALING_CONFIG_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the subcluster to update.

    To get the subcluster ID make a [SubclusterService.List] request.
    """
    name: builtins.str
    """Name of the subcluster."""
    hosts_count: builtins.int
    """Number of hosts in the subcluster."""
    @property
    def resources(self) -> yandex.cloud.dataproc.v1.common_pb2.Resources:
        """Resource configuration for each host in the subcluster."""

    @property
    def autoscaling_config(self) -> yandex.cloud.dataproc.v1.subcluster_pb2.AutoscalingConfig:
        """Configuration for instance group based subclusters"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        resources: yandex.cloud.dataproc.v1.common_pb2.Resources | None = ...,
        hosts_count: builtins.int = ...,
        autoscaling_config: yandex.cloud.dataproc.v1.subcluster_pb2.AutoscalingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["autoscaling_config", b"autoscaling_config", "resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["autoscaling_config", b"autoscaling_config", "hosts_count", b"hosts_count", "id", b"id", "name", b"name", "resources", b"resources"]) -> None: ...

global___UpdateSubclusterConfigSpec = UpdateSubclusterConfigSpec

@typing.final
class CreateClusterConfigSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_ID_FIELD_NUMBER: builtins.int
    HADOOP_FIELD_NUMBER: builtins.int
    SUBCLUSTERS_SPEC_FIELD_NUMBER: builtins.int
    version_id: builtins.str
    """Version of the image for cluster provisioning.

    All available versions are listed in the [documentation](/docs/data-proc/concepts/environment).
    """
    @property
    def hadoop(self) -> yandex.cloud.dataproc.v1.cluster_pb2.HadoopConfig:
        """Data Proc specific options."""

    @property
    def subclusters_spec(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CreateSubclusterConfigSpec]:
        """Specification for creating subclusters."""

    def __init__(
        self,
        *,
        version_id: builtins.str = ...,
        hadoop: yandex.cloud.dataproc.v1.cluster_pb2.HadoopConfig | None = ...,
        subclusters_spec: collections.abc.Iterable[global___CreateSubclusterConfigSpec] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["hadoop", b"hadoop"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hadoop", b"hadoop", "subclusters_spec", b"subclusters_spec", "version_id", b"version_id"]) -> None: ...

global___CreateClusterConfigSpec = CreateClusterConfigSpec

@typing.final
class UpdateClusterConfigSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBCLUSTERS_SPEC_FIELD_NUMBER: builtins.int
    HADOOP_FIELD_NUMBER: builtins.int
    @property
    def subclusters_spec(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UpdateSubclusterConfigSpec]:
        """New configuration for subclusters in a cluster."""

    @property
    def hadoop(self) -> yandex.cloud.dataproc.v1.cluster_pb2.HadoopConfig:
        """Hadoop specific options"""

    def __init__(
        self,
        *,
        subclusters_spec: collections.abc.Iterable[global___UpdateSubclusterConfigSpec] | None = ...,
        hadoop: yandex.cloud.dataproc.v1.cluster_pb2.HadoopConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["hadoop", b"hadoop"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hadoop", b"hadoop", "subclusters_spec", b"subclusters_spec"]) -> None: ...

global___UpdateClusterConfigSpec = UpdateClusterConfigSpec

@typing.final
class CreateClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CONFIG_SPEC_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    UI_PROXY_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    HOST_GROUP_IDS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a cluster in.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the cluster. The name must be unique within the folder.
    The name can't be changed after the Data Proc cluster is created.
    """
    description: builtins.str
    """Description of the cluster."""
    zone_id: builtins.str
    """ID of the availability zone where the cluster should be placed.

    To get the list of available zones make a [yandex.cloud.compute.v1.ZoneService.List] request.
    """
    service_account_id: builtins.str
    """ID of the service account to be used by the Data Proc manager agent."""
    bucket: builtins.str
    """Name of the Object Storage bucket to use for Data Proc jobs."""
    ui_proxy: builtins.bool
    """Enable UI Proxy feature."""
    deletion_protection: builtins.bool
    """Deletion Protection inhibits deletion of the cluster"""
    log_group_id: builtins.str
    """ID of the cloud logging log group to write logs. If not set, logs will not be sent to logging service"""
    environment: yandex.cloud.dataproc.v1.cluster_pb2.Cluster.Environment.ValueType
    """Environment of the cluster"""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Cluster labels as `key:value` pairs."""

    @property
    def config_spec(self) -> global___CreateClusterConfigSpec:
        """Configuration and resources for hosts that should be created with the cluster."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups."""

    @property
    def host_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Host groups to place VMs of cluster on."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        config_spec: global___CreateClusterConfigSpec | None = ...,
        zone_id: builtins.str = ...,
        service_account_id: builtins.str = ...,
        bucket: builtins.str = ...,
        ui_proxy: builtins.bool = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        host_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
        log_group_id: builtins.str = ...,
        environment: yandex.cloud.dataproc.v1.cluster_pb2.Cluster.Environment.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config_spec", b"config_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bucket", b"bucket", "config_spec", b"config_spec", "deletion_protection", b"deletion_protection", "description", b"description", "environment", b"environment", "folder_id", b"folder_id", "host_group_ids", b"host_group_ids", "labels", b"labels", "log_group_id", b"log_group_id", "name", b"name", "security_group_ids", b"security_group_ids", "service_account_id", b"service_account_id", "ui_proxy", b"ui_proxy", "zone_id", b"zone_id"]) -> None: ...

global___CreateClusterRequest = CreateClusterRequest

@typing.final
class CreateClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster that is being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___CreateClusterMetadata = CreateClusterMetadata

@typing.final
class UpdateClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CONFIG_SPEC_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    DECOMMISSION_TIMEOUT_FIELD_NUMBER: builtins.int
    UI_PROXY_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to update.

    To get the cluster ID, make a [ClusterService.List] request.
    """
    description: builtins.str
    """New description for the cluster."""
    name: builtins.str
    """New name for the Data Proc cluster. The name must be unique within the folder."""
    service_account_id: builtins.str
    """ID of the new service account to be used by the Data Proc manager agent."""
    bucket: builtins.str
    """Name of the new Object Storage bucket to use for Data Proc jobs."""
    decommission_timeout: builtins.int
    """Timeout to gracefully decommission nodes. In seconds. Default value: 0"""
    ui_proxy: builtins.bool
    """Enable UI Proxy feature."""
    deletion_protection: builtins.bool
    """Deletion Protection inhibits deletion of the cluster"""
    log_group_id: builtins.str
    """ID of the cloud logging log group to write logs. If not set, logs will not be sent to logging service"""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the cluster should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """A new set of cluster labels as `key:value` pairs."""

    @property
    def config_spec(self) -> global___UpdateClusterConfigSpec:
        """Configuration and resources for hosts that should be created with the Data Proc cluster."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        config_spec: global___UpdateClusterConfigSpec | None = ...,
        name: builtins.str = ...,
        service_account_id: builtins.str = ...,
        bucket: builtins.str = ...,
        decommission_timeout: builtins.int = ...,
        ui_proxy: builtins.bool = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
        log_group_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config_spec", b"config_spec", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bucket", b"bucket", "cluster_id", b"cluster_id", "config_spec", b"config_spec", "decommission_timeout", b"decommission_timeout", "deletion_protection", b"deletion_protection", "description", b"description", "labels", b"labels", "log_group_id", b"log_group_id", "name", b"name", "security_group_ids", b"security_group_ids", "service_account_id", b"service_account_id", "ui_proxy", b"ui_proxy", "update_mask", b"update_mask"]) -> None: ...

global___UpdateClusterRequest = UpdateClusterRequest

@typing.final
class UpdateClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster that is being updated."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___UpdateClusterMetadata = UpdateClusterMetadata

@typing.final
class DeleteClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DECOMMISSION_TIMEOUT_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to delete.

    To get a cluster ID, make a [ClusterService.List] request.
    """
    decommission_timeout: builtins.int
    """Timeout to gracefully decommission nodes. In seconds. Default value: 0"""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        decommission_timeout: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "decommission_timeout", b"decommission_timeout"]) -> None: ...

global___DeleteClusterRequest = DeleteClusterRequest

@typing.final
class DeleteClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Data Proc cluster that is being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___DeleteClusterMetadata = DeleteClusterMetadata

@typing.final
class StartClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to start.

    To get a cluster ID, make a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StartClusterRequest = StartClusterRequest

@typing.final
class StartClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Data Proc cluster that is being started."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StartClusterMetadata = StartClusterMetadata

@typing.final
class StopClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DECOMMISSION_TIMEOUT_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to stop.

    To get a cluster ID, make a [ClusterService.List] request.
    """
    decommission_timeout: builtins.int
    """Timeout to gracefully decommission nodes. In seconds. Default value: 0"""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        decommission_timeout: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "decommission_timeout", b"decommission_timeout"]) -> None: ...

global___StopClusterRequest = StopClusterRequest

@typing.final
class StopClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Data Proc cluster that is being stopped."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StopClusterMetadata = StopClusterMetadata

@typing.final
class ListClusterOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListClusterOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListClusterOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClusterOperationsRequest = ListClusterOperationsRequest

@typing.final
class ListClusterOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListClusterOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListClusterOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified cluster."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListClusterOperationsResponse = ListClusterOperationsResponse

@typing.final
class ListClusterHostsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to list hosts for.

    To get a cluster ID, make a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListClusterHostsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListClusterHostsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters hosts listed in the response.

    The expression must specify:
    1. The field name. Currently you can use filtering only on [Cluster.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name=my-host`
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClusterHostsRequest = ListClusterHostsRequest

@typing.final
class ListClusterHostsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOSTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListClusterHostsRequest.page_size], use `next_page_token` as the value
    for the [ListClusterHostsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.dataproc.v1.subcluster_pb2.Host]:
        """Requested list of hosts."""

    def __init__(
        self,
        *,
        hosts: collections.abc.Iterable[yandex.cloud.dataproc.v1.subcluster_pb2.Host] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["hosts", b"hosts", "next_page_token", b"next_page_token"]) -> None: ...

global___ListClusterHostsResponse = ListClusterHostsResponse

@typing.final
class ListUILinksRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the Hadoop cluster."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___ListUILinksRequest = ListUILinksRequest

@typing.final
class UILink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    name: builtins.str
    url: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "url", b"url"]) -> None: ...

global___UILink = UILink

@typing.final
class ListUILinksResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LINKS_FIELD_NUMBER: builtins.int
    @property
    def links(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UILink]:
        """Requested list of ui links."""

    def __init__(
        self,
        *,
        links: collections.abc.Iterable[global___UILink] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["links", b"links"]) -> None: ...

global___ListUILinksResponse = ListUILinksResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.vpc.v1.privatelink.private_endpoint_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetPrivateEndpointRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_ENDPOINT_ID_FIELD_NUMBER: builtins.int
    private_endpoint_id: builtins.str
    """ID of the PrivateEndpoint resource to return.

    To get PrivateEndpoint resource ID make a [PrivateEndpointService.List]
    request.
    """
    def __init__(
        self,
        *,
        private_endpoint_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_endpoint_id", b"private_endpoint_id"]) -> None: ...

global___GetPrivateEndpointRequest = GetPrivateEndpointRequest

@typing.final
class InternalIpv4AddressSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_ID_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    """ID of the subnet that address belongs to."""
    address: builtins.str
    """Value of address."""
    def __init__(
        self,
        *,
        subnet_id: builtins.str = ...,
        address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "subnet_id", b"subnet_id"]) -> None: ...

global___InternalIpv4AddressSpec = InternalIpv4AddressSpec

@typing.final
class AddressSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_ID_FIELD_NUMBER: builtins.int
    INTERNAL_IPV4_ADDRESS_SPEC_FIELD_NUMBER: builtins.int
    address_id: builtins.str
    """ID of IP address to associate with private endpoint."""
    @property
    def internal_ipv4_address_spec(self) -> global___InternalIpv4AddressSpec:
        """Internal ipv4 address specification."""

    def __init__(
        self,
        *,
        address_id: builtins.str = ...,
        internal_ipv4_address_spec: global___InternalIpv4AddressSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["address", b"address", "address_id", b"address_id", "internal_ipv4_address_spec", b"internal_ipv4_address_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "address_id", b"address_id", "internal_ipv4_address_spec", b"internal_ipv4_address_spec"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["address", b"address"]) -> typing.Literal["address_id", "internal_ipv4_address_spec"] | None: ...

global___AddressSpec = AddressSpec

@typing.final
class CreatePrivateEndpointRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    ADDRESS_SPEC_FIELD_NUMBER: builtins.int
    DNS_OPTIONS_FIELD_NUMBER: builtins.int
    OBJECT_STORAGE_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a private endpoint in.

    To get a folder ID make a
    [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the private endpoint.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the private endpoint."""
    network_id: builtins.str
    """ID of the network to create a private endpoint in."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Private endpoint labels as `key:value` pairs."""

    @property
    def address_spec(self) -> global___AddressSpec:
        """Private endpoint address specification."""

    @property
    def dns_options(self) -> yandex.cloud.vpc.v1.privatelink.private_endpoint_pb2.PrivateEndpoint.DnsOptions:
        """Private endpoint dns options."""

    @property
    def object_storage(self) -> yandex.cloud.vpc.v1.privatelink.private_endpoint_pb2.PrivateEndpoint.ObjectStorage:
        """Yandex Cloud Object Storage."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        network_id: builtins.str = ...,
        address_spec: global___AddressSpec | None = ...,
        dns_options: yandex.cloud.vpc.v1.privatelink.private_endpoint_pb2.PrivateEndpoint.DnsOptions | None = ...,
        object_storage: yandex.cloud.vpc.v1.privatelink.private_endpoint_pb2.PrivateEndpoint.ObjectStorage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["address_spec", b"address_spec", "dns_options", b"dns_options", "object_storage", b"object_storage", "service", b"service"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["address_spec", b"address_spec", "description", b"description", "dns_options", b"dns_options", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "network_id", b"network_id", "object_storage", b"object_storage", "service", b"service"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["service", b"service"]) -> typing.Literal["object_storage"] | None: ...

global___CreatePrivateEndpointRequest = CreatePrivateEndpointRequest

@typing.final
class CreatePrivateEndpointMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_ENDPOINT_ID_FIELD_NUMBER: builtins.int
    private_endpoint_id: builtins.str
    """ID of the private endpoint that is being created."""
    def __init__(
        self,
        *,
        private_endpoint_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_endpoint_id", b"private_endpoint_id"]) -> None: ...

global___CreatePrivateEndpointMetadata = CreatePrivateEndpointMetadata

@typing.final
class UpdatePrivateEndpointRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    PRIVATE_ENDPOINT_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ADDRESS_SPEC_FIELD_NUMBER: builtins.int
    DNS_OPTIONS_FIELD_NUMBER: builtins.int
    private_endpoint_id: builtins.str
    """ID of the private endpoint to update.

    To get the private endpoint ID make a [PrivateEndpointService.List]
    request.
    """
    name: builtins.str
    """New name for the private endpoint.
    The name must be unique within the folder.
    """
    description: builtins.str
    """New description of the private endpoint."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the PrivateEndpoint should be
        updated.
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Private endpoint labels as `key:value` pairs.

        Existing set of labels is completely replaced by the provided set, so if
        you just want to add or remove a label:
        1. Get the current set of labels with a [PrivateEndpointService.Get]
        request.
        2. Add or remove a label in this set.
        3. Send the new set in this field.
        """

    @property
    def address_spec(self) -> global___AddressSpec:
        """Private endpoint address specification."""

    @property
    def dns_options(self) -> yandex.cloud.vpc.v1.privatelink.private_endpoint_pb2.PrivateEndpoint.DnsOptions:
        """Private endpoint dns options."""

    def __init__(
        self,
        *,
        private_endpoint_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        address_spec: global___AddressSpec | None = ...,
        dns_options: yandex.cloud.vpc.v1.privatelink.private_endpoint_pb2.PrivateEndpoint.DnsOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["address_spec", b"address_spec", "dns_options", b"dns_options", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["address_spec", b"address_spec", "description", b"description", "dns_options", b"dns_options", "labels", b"labels", "name", b"name", "private_endpoint_id", b"private_endpoint_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdatePrivateEndpointRequest = UpdatePrivateEndpointRequest

@typing.final
class UpdatePrivateEndpointMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_ENDPOINT_ID_FIELD_NUMBER: builtins.int
    private_endpoint_id: builtins.str
    """ID of the private endpoint that is being updated."""
    def __init__(
        self,
        *,
        private_endpoint_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_endpoint_id", b"private_endpoint_id"]) -> None: ...

global___UpdatePrivateEndpointMetadata = UpdatePrivateEndpointMetadata

@typing.final
class DeletePrivateEndpointRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_ENDPOINT_ID_FIELD_NUMBER: builtins.int
    private_endpoint_id: builtins.str
    """ID of the private endpoint to delete.

    To get a private endpoint ID make a [PrivateEndpointService.List] request.
    """
    def __init__(
        self,
        *,
        private_endpoint_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_endpoint_id", b"private_endpoint_id"]) -> None: ...

global___DeletePrivateEndpointRequest = DeletePrivateEndpointRequest

@typing.final
class DeletePrivateEndpointMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_ENDPOINT_ID_FIELD_NUMBER: builtins.int
    private_endpoint_id: builtins.str
    """ID of the private endpoint that is being deleted."""
    def __init__(
        self,
        *,
        private_endpoint_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_endpoint_id", b"private_endpoint_id"]) -> None: ...

global___DeletePrivateEndpointMetadata = DeletePrivateEndpointMetadata

@typing.final
class ListPrivateEndpointsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list private endpoints in.

    To get the folder ID use a
    [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of
    available results is larger than `page_size`, the service returns a
    [ListPrivateEndpointsResponse.next_page_token] that can be used to get the
    next page of results in subsequent list requests. Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListPrivateEndpointsResponse.next_page_token] returned by a previous list
    request.
    """
    filter: builtins.str
    """A filter expression that filters PrivateEndpoint listed in the response.

    The expression must specify:
    1. The field name. Currently you can use filtering only on
    [PrivateEndpoint.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match
    the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`. Example of a filter:
    `name=my-private-endpoint`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["container", b"container", "folder_id", b"folder_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["container", b"container", "filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["container", b"container"]) -> typing.Literal["folder_id"] | None: ...

global___ListPrivateEndpointsRequest = ListPrivateEndpointsRequest

@typing.final
class ListPrivateEndpointsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_ENDPOINTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is
    greater than the specified [ListPrivateEndpointsRequest.page_size], use
    `next_page_token` as the value for the
    [ListPrivateEndpointsRequest.page_token] parameter in the next list
    request.

    Each subsequent page will have its own `next_page_token` to continue paging
    through the results.
    """
    @property
    def private_endpoints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.vpc.v1.privatelink.private_endpoint_pb2.PrivateEndpoint]:
        """List of private endpoints."""

    def __init__(
        self,
        *,
        private_endpoints: collections.abc.Iterable[yandex.cloud.vpc.v1.privatelink.private_endpoint_pb2.PrivateEndpoint] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "private_endpoints", b"private_endpoints"]) -> None: ...

global___ListPrivateEndpointsResponse = ListPrivateEndpointsResponse

@typing.final
class ListPrivateEndpointOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_ENDPOINT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    private_endpoint_id: builtins.str
    """ID of the private endpoint to list operations for.

    To get a private endpoint ID make a [PrivateEndpointService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of
    available results is larger than [page_size], the service returns a
    [ListPrivateEndpointOperationsResponse.next_page_token] that can be used to
    get the next page of results in subsequent list requests. Default value:
    100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListPrivateEndpointOperationsResponse.next_page_token] returned by a
    previous list request.
    """
    def __init__(
        self,
        *,
        private_endpoint_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "private_endpoint_id", b"private_endpoint_id"]) -> None: ...

global___ListPrivateEndpointOperationsRequest = ListPrivateEndpointOperationsRequest

@typing.final
class ListPrivateEndpointOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is
    greater than the specified
    [ListPrivateEndpointOperationsRequest.page_size], use `next_page_token` as
    the value for the [ListPrivateEndpointOperationsRequest.page_token]
    parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging
    through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified private endpoint."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListPrivateEndpointOperationsResponse = ListPrivateEndpointOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.mdb.spqr.v1.resource_preset_pb2
import yandex.cloud.mdb.spqr.v1.resource_preset_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ResourcePresetServiceStub:
    """A set of methods for managing ResourcePreset resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.resource_preset_service_pb2.GetResourcePresetRequest,
        yandex.cloud.mdb.spqr.v1.resource_preset_pb2.ResourcePreset,
    ]
    """Returns the specified ResourcePreset resource.

    To get the list of available ResourcePreset resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.resource_preset_service_pb2.ListResourcePresetsRequest,
        yandex.cloud.mdb.spqr.v1.resource_preset_service_pb2.ListResourcePresetsResponse,
    ]
    """Retrieves the list of available ResourcePreset resources."""

class ResourcePresetServiceAsyncStub:
    """A set of methods for managing ResourcePreset resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.resource_preset_service_pb2.GetResourcePresetRequest,
        yandex.cloud.mdb.spqr.v1.resource_preset_pb2.ResourcePreset,
    ]
    """Returns the specified ResourcePreset resource.

    To get the list of available ResourcePreset resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.resource_preset_service_pb2.ListResourcePresetsRequest,
        yandex.cloud.mdb.spqr.v1.resource_preset_service_pb2.ListResourcePresetsResponse,
    ]
    """Retrieves the list of available ResourcePreset resources."""

class ResourcePresetServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing ResourcePreset resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.mdb.spqr.v1.resource_preset_service_pb2.GetResourcePresetRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.spqr.v1.resource_preset_pb2.ResourcePreset, collections.abc.Awaitable[yandex.cloud.mdb.spqr.v1.resource_preset_pb2.ResourcePreset]]:
        """Returns the specified ResourcePreset resource.

        To get the list of available ResourcePreset resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.mdb.spqr.v1.resource_preset_service_pb2.ListResourcePresetsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.spqr.v1.resource_preset_service_pb2.ListResourcePresetsResponse, collections.abc.Awaitable[yandex.cloud.mdb.spqr.v1.resource_preset_service_pb2.ListResourcePresetsResponse]]:
        """Retrieves the list of available ResourcePreset resources."""

def add_ResourcePresetServiceServicer_to_server(servicer: ResourcePresetServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
